@@ -3,7 +3,8 @@ import configparser
 
 def db_config() -> dict[str, str]:
     config = configparser.ConfigParser()
-    config.read('simple_async_mq_server/config.ini')
+    # config.read('simple_async_mq_server/config.ini')
+    config.read('config.ini')
     return config['database']
 
 def reporting_to_dashboard() -> bool:
@@ -22,7 +23,8 @@ def save_to_config(db_config: dict, report_to_dashboard=False):
     config.set('database', 'password', db_config['password'])
     config.set('database', 'database', db_config['database'])
 
-    with open('simple_async_mq_server/config.ini', 'w+') as configfile:
+    # with open('simple_async_mq_server/config.ini', 'w+') as configfile:
+    with open('config.ini', 'w+') as configfile:
         config.write(configfile)
 
 if __name__ == '__main__':
